@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "17.0.4.1";
+        "17.0.6";
 
     private static final String java_version_date =
-        "2022-08-12";
+        "2023-01-17";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "17.0.4.1+1";
+        "17.0.6+10";
 
     private static final String VERSION_NUMBER =
-        "17.0.4.1";
+        "17.0.6";
 
     private static final String VERSION_SPECIFICATION =
         "17";
 
     private static final String VERSION_BUILD =
-        "1";
+        "10";
 
     private static final String VERSION_PRE =
         "";
